==> unifetch-0.1.0.tar.gz: unifetch-0.1.0/README.md <==
# Unifetch

Unifetch is a python script that will display the logo and motto of a UK university.

It's main purpose is to be used as a welcome message on a University ssh server or maybe just a local vm you use for uni work.

Feel free to add any Academic institution logo you feel like.

## Example

![example](README_IMAGES/example.png)

## Usage
```
usage: unifetch [-h] [--num-cols NUM_COLS] [--show-unis [SHOW_UNIS]] [--logo-only [LOGO_ONLY]] [uni]

Take image for processing

positional arguments:
  uni                   University short name, for a list of universities type --show-unis

optional arguments:
  -h, --help            show this help message and exit
  --num-cols NUM_COLS   Width of logo in text columns
  --show-unis [SHOW_UNIS]
  --logo-only [LOGO_ONLY]
```

## Universities
```
abdn - University of Aberdeen
bath - University of Bath
bham - University of Birmingham
bris - University of Bristol
cam - University of Cambridge
cf - Cardiff University
cov - Coventry University
dmu - De Montfort University
dundee - University of Dundee
dur - Durham University
ed - University of Edinburgh
essex - University of Essex
ex - University of Exeter
gla - University of Glasgow
harper-adams - Harper Adams University
hw - Herriot-Watt University
ic - Imperial College London
kcl - King's College London
lancs - Lancaster University
lboro - Loughborough University
le - University of Leicester
leeds - University of Leeds
liv - University of Liverpool
lse - London School of Economics and Political Science
man - University of Manchester
mmu - Manchester Metropolitan University
ncl - Newcastle University
northumbria - Northumbria University
nott - University of Nottingham
ntu - Nottingham Trent University
ox - University of Oxford
port - University of Portsmouth
qmw - Queen Mary University of London
qub - Queen's University Belfast
rdg - University of Reading
rhul - Royal Holloway, University of London
shef - University of Sheffield
shu - Sheffield Hallam University
soton - University of Southampton
st-and - University of St Andrews
stir - University of Stirling
strath - University of Strathclyde
sund - University of Sunderland
surrey - University of Surrey
susx - University of Sussex
swan - Swansea University
tees - Teesside University
ucl - University College London
uea - University of East Anglia
uwe - University of the West of England, Bristol
warwick - University of Warwick
york - University of York
```

==> unifetch-0.1.3.tar.gz: unifetch-0.1.3/README.md <==
# Unifetch

Unifetch is a python script that will display the logo and motto of a UK university.

It's main purpose is to be used as a welcome message on a University ssh server or maybe just a local vm you use for uni work.

Feel free to add any Academic institution logo you feel like.

## Example

![example](https://github.com/LukeBriggsDev/unifetch/raw/master/README_IMAGES/example.png)

## Usage
```
usage: unifetch [-h] [--num-cols NUM_COLS] [--show-unis [SHOW_UNIS]] [--logo-only [LOGO_ONLY]] [uni]

Take image for processing

positional arguments:
  uni                   University short name, for a list of universities type --show-unis

optional arguments:
  -h, --help            show this help message and exit
  --num-cols NUM_COLS   Width of logo in text columns
  --show-unis [SHOW_UNIS]
  --logo-only [LOGO_ONLY]
```

## Universities
``` 
abdn - University of Aberdeen
bath - University of Bath
bham - University of Birmingham
bris - University of Bristol
cam - University of Cambridge
cf - Cardiff University
cov - Coventry University
dmu - De Montfort University
dundee - University of Dundee
dur - Durham University
ed - University of Edinburgh
essex - University of Essex
ex - University of Exeter
gla - University of Glasgow
harper-adams - Harper Adams University
hw - Herriot-Watt University
ic - Imperial College London
kcl - King's College London
lancs - Lancaster University
lboro - Loughborough University
le - University of Leicester
leeds - University of Leeds
liv - University of Liverpool
lse - London School of Economics and Political Science
man - University of Manchester
mmu - Manchester Metropolitan University
ncl - Newcastle University
northumbria - Northumbria University
nott - University of Nottingham
ntu - Nottingham Trent University
ox - University of Oxford
port - University of Portsmouth
qmw - Queen Mary University of London
qub - Queen's University Belfast
rdg - University of Reading
rhul - Royal Holloway, University of London
shef - University of Sheffield
shu - Sheffield Hallam University
soton - University of Southampton
st-and - University of St Andrews
stir - University of Stirling
strath - University of Strathclyde
sund - University of Sunderland
surrey - University of Surrey
susx - University of Sussex
swan - Swansea University
tees - Teesside University
ucl - University College London
uea - University of East Anglia
uwe - University of the West of England, Bristol
warwick - University of Warwick
york - University of York
```
